package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.SjGfjsLbzdbfJg;

/**
 * 规范建设-练兵指导帮扶结果Service接口
 * 
 * @author qianhe
 * @date 2025-08-19
 */
public interface ISjGfjsLbzdbfJgService 
{
    /**
     * 查询规范建设-练兵指导帮扶结果
     * 
     * @param id 规范建设-练兵指导帮扶结果主键
     * @return 规范建设-练兵指导帮扶结果
     */
    public SjGfjsLbzdbfJg selectSjGfjsLbzdbfJgById(Long id);

    /**
     * 查询规范建设-练兵指导帮扶结果列表
     * 
     * @param sjGfjsLbzdbfJg 规范建设-练兵指导帮扶结果
     * @return 规范建设-练兵指导帮扶结果集合
     */
    public List<SjGfjsLbzdbfJg> selectSjGfjsLbzdbfJgList(SjGfjsLbzdbfJg sjGfjsLbzdbfJg);

    /**
     * 新增规范建设-练兵指导帮扶结果
     * 
     * @param sjGfjsLbzdbfJg 规范建设-练兵指导帮扶结果
     * @return 结果
     */
    public int insertSjGfjsLbzdbfJg(SjGfjsLbzdbfJg sjGfjsLbzdbfJg);

    /**
     * 修改规范建设-练兵指导帮扶结果
     * 
     * @param sjGfjsLbzdbfJg 规范建设-练兵指导帮扶结果
     * @return 结果
     */
    public int updateSjGfjsLbzdbfJg(SjGfjsLbzdbfJg sjGfjsLbzdbfJg);

    /**
     * 批量删除规范建设-练兵指导帮扶结果
     * 
     * @param ids 需要删除的规范建设-练兵指导帮扶结果主键集合
     * @return 结果
     */
    public int deleteSjGfjsLbzdbfJgByIds(Long[] ids);

    /**
     * 删除规范建设-练兵指导帮扶结果信息
     * 
     * @param id 规范建设-练兵指导帮扶结果主键
     * @return 结果
     */
    public int deleteSjGfjsLbzdbfJgById(Long id);
}
